@@ -159,16 +159,21 @@ setReplaceMethod("site", "SoilProfileCollection",
       suppressMessages(site.new <- join(s, value, type='left'))
       
       # sanity check: site + new data should have same number of rows as original
-      if(nrow(s) != nrow(site.new))
+      if(nrow(s) != nrow(site.new)) {
+      	cat(paste('original data (', nrow(s), ' rows) new data (', nrow(site.new), ' rows)', sep=''))
         stop('invalid join condition, site data not changed', call.=FALSE)
+      }
             
       # look good, proceed
       object@site <- site.new
 	  }
-  
+  	
+    ## TODO: finer reporting on what the problem might be
     # check to make sure the the number of rows in @site is the same as length(object)
-    if(length(object) != nrow(site(object)))
+    if(length(object) != nrow(site(object))){
+    	print(paste('pedons (', length(object), ') rows of site data (', nrow(site(object)), ')', sep=''))
     	stop('invalid site data, non-unique values present in horizon data?', call.=FALSE)
+    }
     
     # done
     return(object)
